==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Transports/mms/translations/mms_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="34"/>
        <source>MMS Plugin</source>
        <translation>Модуль MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>About MMS Transport Plugin</source>
        <translation>Про модуль MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="55"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>Транспортний модуль MMS для Qmmp</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="56"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>Налаштування модуля MMS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Розмір буфера:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Transports/mms/translations/mms_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>MMSInputFactory</name>
    <message>
        <location filename="../mmsinputfactory.cpp" line="33"/>
        <source>MMS Plugin</source>
        <translation>Модуль MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="53"/>
        <source>About MMS Transport Plugin</source>
        <translation>Про модуль MMS</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="54"/>
        <source>Qmmp MMS Transport Plugin</source>
        <translation>Транспортний модуль MMS для Qmmp</translation>
    </message>
    <message>
        <location filename="../mmsinputfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MMS Plugin Settings</source>
        <translation>Налаштування модуля MMS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Buffer size:</source>
        <translation>Розмір буфера:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>KB</source>
        <translation>Кб</translation>
    </message>
</context>
</TS>
